@@ -47,7 +47,13 @@ mat_to_rowcolval <- function(.matrix, matvals = "matvals",
                              rownames = "rownames", colnames = "colnames",
                              rowtypes = "rowtypes", coltypes = "coltypes",
                              drop = NA){
-  if (is.matrix(.matrix)) {
+  if (matsbyname::is_matrix_or_Matrix(.matrix)) {
+    if (matsbyname::is.Matrix(.matrix)) {
+      temp <- as.matrix(.matrix) %>%
+        matsbyname::setrowtype(matsbyname::rowtype(.matrix)) %>%
+        matsbyname::setcoltype(matsbyname::coltype(.matrix))
+      .matrix <- temp
+    }
     out <- .matrix %>%
       data.frame(check.names = FALSE, stringsAsFactors = FALSE) %>%
       tibble::rownames_to_column(var = rownames) %>%
@@ -83,6 +89,11 @@ mat_to_rowcolval <- function(.matrix, matvals = "matvals",
 #' it is assumed that this is a single value, not a matrix,
 #' in which case the value in the `values` column is returned.
 #'
+#' Note that two types of matrices can be created, a `matrix` or a `Matrix`.
+#' `Matrix` has the advantage of representing sparse matrices with less memory
+#' (and disk space).
+#' `Matrix` objects are created by `matsbyname::Matrix()`.
+#'
 #' @param .DF       A tidy data frame containing columns for row names, column names, and values.
 #' @param matvals   The name of the column in `.DF` containing values with which to fill the matrix (a string). Default is "matvals".
 #' @param rownames  The name of the column in `.DF` containing row names (a string). Default is "rownames".
@@ -90,6 +101,12 @@ mat_to_rowcolval <- function(.matrix, matvals = "matvals",
 #' @param rowtypes  An optional string identifying the types of information found in rows of the matrix to be constructed. Default is "rowtypes".
 #' @param coltypes  An optional string identifying the types of information found in columns of the matrix to be constructed. Default is "coltypes".
 #' @param fill      The value for missing entries in the resulting matrix. default is `0`.
+#' @param matrix.class `r lifecycle::badge("deprecated")` Use `matrix_class` instead.
+#' @param matrix_class One of "matrix" or "Matrix".
+#'                     "matrix" creates a `base::matrix` object with the `matrix()` function.
+#'                     "Matrix" creates a `Matrix::Matrix` object using the `matsbyname::Matrix()` function.
+#'                     This could be a sparse matrix.
+#'                     Default is "matrix".
 #'
 #' @return A matrix with named rows and columns and, optionally, row and column types.
 #'
@@ -128,7 +145,19 @@ mat_to_rowcolval <- function(.matrix, matvals = "matvals",
 #'                           matvals = "vals", rowtypes = "rt", coltypes = "ct")}
 rowcolval_to_mat <- function(.DF, matvals = "matvals",
                              rownames = "rownames", colnames = "colnames",
-                             rowtypes = "rowtypes", coltypes = "coltypes", fill = 0){
+                             rowtypes = "rowtypes", coltypes = "coltypes",
+                             fill = 0,
+                             matrix.class = lifecycle::deprecated(),
+                             matrix_class = c("matrix", "Matrix")) {
+  if (lifecycle::is_present(matrix.class)) {
+    lifecycle::deprecate_warn(when = "0.4.3",
+                              what = "create_matrix_byname(matrix.class)",
+                              with = "create_matrix_byname(matrix_class)")
+    matrix_class <- matrix.class
+  }
+
+  matrix_class <- match.arg(matrix_class)
+
   if (!is.null(rowtypes)) {
     # If rowtype is supplied and is not NA, check if it is one of the columns of .DF
     if (rowtypes %in% colnames(.DF)) {
@@ -174,7 +203,7 @@ rowcolval_to_mat <- function(.DF, matvals = "matvals",
   # The remainder of the rows have matrix information stored in the columns
   # rownames, colnames, rowtype, coltype
   # Put that data in a matrix and return it.
-  .DF %>%
+  out <- .DF %>%
     dplyr::select(!!rownames, !!colnames, !!matvals) %>%
     # It is possible to have rows with the same Industry in .DF,
     # because multiple fuel sources can make the same type of output
@@ -191,8 +220,13 @@ rowcolval_to_mat <- function(.DF, matvals = "matvals",
     tibble::column_to_rownames(var = rownames) %>%
     as.matrix() %>%
     matsbyname::setrowtype(rowtype = rowtypes) %>% matsbyname::setcoltype(coltype = coltypes)
+  if (matrix_class == "Matrix") {
+    out <- matsbyname::Matrix(out)
+  }
+  return(out)
 }
 
+
 #' Index a column in a data frame by groups relative to an initial year
 #'
 #' This function indexes (by ratio) variables in \code{vars_to_index}
@@ -577,9 +611,11 @@ df_to_msg <- function(df) {
 #' @param .any A boolean that tells whether a column is reported when
 #'             `any()` of the rows contain matrices
 #'             (instead of `all()` rows contain matrices).
-#'             Default is `FALSE`.
+#'             Default is `FALSE`, in which case
+#'             all entries in a column must be a matrix for
+#'             the column to be reported.
 #'
-#' @return A vector of integers saying which columns contain solely matrices.
+#' @return A vector of integers saying which columns contain matrices.
 #'
 #' @export
 #'
@@ -605,7 +641,7 @@ matrix_cols <- function(.df, .drop_names = FALSE, .any = FALSE) {
   out <- sapply(cnames, FUN = function(this_cname) {
     this_col <- .df[[this_cname]]
     true_false <- sapply(this_col, FUN = function(this_item) {
-      is.matrix(this_item)
+      matsbyname::is_matrix_or_Matrix(this_item)
     })
     if (.any) {
       return(any(true_false))
